Event Type - Betty 0.4.0a1 documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# Event Type

Event types are what indicate what kind of thing an event is about, such as a birth, death, or marriage. They inherit from `betty.model.event_type.EventType`.

## Event types

`betty.model.event_type.Adoption`

  A person’s adoption.

`betty.model.event_type.Baptism`

  A person’s baptism.

`betty.model.event_type.Birth`

  A person’s birth. This event type often receives special treatment and is considered the authoritative type to determine when somebody’s life started.

`betty.model.event_type.Burial`

  A person’s burial.

`betty.model.event_type.Conference`

  A conference.

`betty.model.event_type.Confirmation`

  A christian confirmation.

`betty.model.event_type.Correspondence`

  Correspondence between people, such as letters or emails.

`betty.model.event_type.Cremation`

  A person’s cremation.

`betty.model.event_type.Death`

  A person’s death. This event type often receives special treatment and is considered the authoritative type to determine when somebody’s life ended.

`betty.model.event_type.Divorce`

  A person’s divorce from another.

`betty.model.event_type.DivorceAnnouncement`

  The public announcement of a person’s divorce from another.

`betty.model.event_type.Emigration`

  A person’s emigration from a place.

`betty.model.event_type.Engagement`

  A person’s engagement to another.

`betty.model.event_type.Funeral`

  A person’s funeral.

`betty.model.event_type.Immigration`

  A person’s immigration to a place.

`betty.model.event_type.Marriage`

  A person’s marriage to another.

`betty.model.event_type.MarriageAnnouncement`

  The public announcement of a person’s marriage to another, such as marriage banns.

`betty.model.event_type.Missing`

  When someone has become a missing person.

`betty.model.event_type.Occupation`

  How a person spends their time in society, such as through employment or education.

`betty.model.event_type.Residence`

  A person stayed or lived in a place for some time.

`betty.model.event_type.Retirement`

  A person’s retirement from their occupations.

`betty.model.event_type.UnknownEventType`

  The event’s type is not otherwise known.

`betty.model.event_type.Will`

  Any event associated with the reading and excution of someone’s will and testament.

## Meta event types

The aforementioned event types can inherit from these meta types. For example, births and baptisms are both start-of-life events.

`betty.model.event_type.StartOfLifeEventType`

  Any event taking place because of and close to someone’s birth, such as a baptism, or an actual birth.

`betty.model.event_type.DuringLifeEventType`

  Any event taking place while the subject was still alive, e.g. between their birth and death.

`betty.model.event_type.EndOfLifeEventType`

  Any event taking place because of and close to someone’s death, such as a funeral, or an actual death.

`betty.model.event_type.PostDeathEventType`

  Any event taking place after someone’s death, such as a funeral or will reading.

`betty.model.event_type.FinalDispositionEventType`

  Any final disposition, such as a burial or cremation.